@@ -1,5 +1,4 @@
 use actix_web::web;
-use log::debug;
 use reqwest::Client;
 
 use crate::error;
@@ -8,7 +7,6 @@ pub async fn get(
     client: &web::Data<Client>,
     url: &String,
 ) -> Result<serde_json::Value, error::FunesError> {
-    debug!("External get to: {}", url);
     Ok(client
         .get(url)
         .send()
@@ -24,7 +22,6 @@ pub async fn post(
     url: &String,
     payload: &serde_json::Value,
 ) -> Result<serde_json::Value, error::FunesError> {
-    debug!("External post to: {}", url);
     Ok(client
         .post(url)
         .json(payload)
